{% extends 'toga/base.html' %}
{% block title %}{{ window.title }}{% endblock %}
{% block bytecode %}
        <script id="batavia-toga" type="application/python-bytecode">
{{ toga }}
        </script>
        <script id="batavia-bootstrap" type="application/python-bytecode">
{{ bootstrap }}
        </script>
    {% for name, payload in callbacks.items %}
        <script id="batavia-{{ name }}" type="application/python-bytecode">
{{ payload }}
        </script>
    {% endfor %}
{% endblock %}
{% block content %}
        {{ window.html }}

        <hr>
        <pre id="stdout"></pre>

        <script src="{% static 'jquery/dist/jquery.js' %}"></script>
        <script src="{% static 'toga/batavia.js' %}"></script>
        <script src="{% static 'toga/toga.js' %}"></script>
{% endblock %}
